@@ -5,10 +5,16 @@ from icevision import tfms
 from icevision.data import *
 from icevision import backbones
 from icevision import models
-from icevision.models import *
 from icevision.metrics import *
 from icevision.visualize import *
 
+# HACK: Only for presentation, need to fix namespace
+from icevision.parsers import Parser
+
+
+# HACK: quickfix because models import torchvision
+import torchvision
+
 try:
     import importlib.metadata as importlib_metadata
 except ModuleNotFoundError:
