@@ -8,8 +8,11 @@ __all__ = [
     "BaseLabelsRecordComponent",
     "InstancesLabelsRecordComponent",
     "ClassificationLabelsRecordComponent",
+    "GrayScaleRecordComponent",
     "BBoxesRecordComponent",
-    "MasksRecordComponent",
+    "BaseMasksRecordComponent",
+    "InstanceMasksRecordComponent",
+    "SemanticMaskRecordComponent",
     "AreasRecordComponent",
     "IsCrowdsRecordComponent",
     "KeyPointsRecordComponent",
@@ -17,6 +20,7 @@ __all__ = [
     "LossesRecordComponent",
 ]
 
+from icevision.utils.imageio import open_gray_scale_image
 from icevision.imports import *
 from icevision.utils import *
 from icevision.core.components import *
@@ -49,9 +53,6 @@ class RecordComponent(TaskComponent):
     def _autofix(self) -> Dict[str, bool]:
         return {}
 
-    def _remove_annotation(self, i) -> None:
-        return
-
     def _aggregate_objects(self) -> Dict[str, List[dict]]:
         return {}
 
@@ -115,7 +116,7 @@ class ImageRecordComponent(RecordComponent):
         assert isinstance(img, (PIL.Image.Image, np.ndarray))
         self.img = img
         if isinstance(img, PIL.Image.Image):
-            height, width = img.shape
+            width, height = img.size
         elif isinstance(img, np.ndarray):
             # else:
             height, width, _ = self.img.shape
@@ -136,7 +137,7 @@ class ImageRecordComponent(RecordComponent):
                     )
                 return [f"Img: {width}x{height}x{channels} <np.ndarray> Image"]
             elif isinstance(self.img, PIL.Image.Image):
-                height, width = self.img.shape
+                width, height = self.img.size
                 return [f"Img: {width}x{height} <PIL.Image; mode='{self.img.mode}'>"]
         else:
             return [f"Img: {self.img}"]
@@ -152,15 +153,18 @@ class ImageRecordComponent(RecordComponent):
 
 
 class FilepathRecordComponent(ImageRecordComponent):
-    def __init__(self, task=tasks.common):
+    def __init__(self, task=tasks.common, gray=False):
         super().__init__(task=task)
+        self.gray = gray
         self.filepath = None
 
     def set_filepath(self, filepath: Union[str, Path]):
         self.filepath = Path(filepath)
 
     def _load(self):
-        img = open_img(self.filepath)
+        img = open_img(self.filepath, gray=self.gray)
+        if self.gray:
+            img = img.convert("RGB")
         self.set_img(img)
 
     def _autofix(self) -> Dict[str, bool]:
@@ -216,6 +220,14 @@ class SizeRecordComponent(RecordComponent):
         return ["record{task}set_img_size(<ImgSize>)"]
 
 
+class GrayScaleRecordComponent(FilepathRecordComponent):
+    """Overwrites the FilepathRecordComponent to load radiographic images like 16bit grayscale tiff images."""
+
+    def _load(self):
+        img = open_gray_scale_image(self.filepath)
+        self.set_img(img)
+
+
 ### Annotation parsers ###
 class BaseLabelsRecordComponent(ClassMapRecordComponent):
     def __init__(self, task=tasks.common):
@@ -376,44 +388,151 @@ class BBoxesRecordComponent(RecordComponent):
         return ["record{task}add_bboxes(<Sequence[BBox]>)"]
 
 
-class MasksRecordComponent(RecordComponent):
-    def __init__(self, task=tasks.detection):
+class BaseMasksRecordComponent(RecordComponent):
+    def __init__(self, task):
         super().__init__(task=task)
-        self.masks = EncodedRLEs()
-
-    def set_masks(self, masks: Sequence[Mask]):
-        self.masks = masks
+        # masks are each individual part that composes the mask
+        # e.g. we can have multiple polygons, rles, etc
+        self.masks = self.mask_parts = []
+        self.mask_array: MaskArray = None
 
     def add_masks(self, masks: Sequence[Mask]):
-        self.masks.extend(self._masks_to_erle(masks))
+        self.masks.extend(masks)
+
+    def set_masks(self, masks: Sequence[Mask]):
+        self.masks.clear()
+        self.masks.extend(masks)
+
+    def set_mask(self, mask: Mask):
+        return self.set_masks([mask])
+
+    def set_mask_array(self, mask_array: MaskArray):
+        self.mask_array = mask_array
+
+    def _load(self):
+        mask_array = MaskArray.from_masks(
+            self.masks, self.composite.height, self.composite.width
+        )
+        self.set_mask_array(mask_array)
+
+    def _unload(self):
+        self.mask_array = None
 
     def setup_transform(self, tfm) -> None:
         tfm.setup_masks(self)
 
-    def _masks_to_erle(self, masks: Sequence[Mask]) -> List[Mask]:
-        width, height = self.composite.img_size
-        return [mask.to_erles(h=height, w=width) for mask in masks]
-
-    def _load(self):
-        self.masks = MaskArray.from_masks(
-            self.masks, self.composite.height, self.composite.width
-        )
-
-    def _unload(self):
-        # TODO: SLOW: Maybe cause slowdowns?
-        self.masks = self.masks.to_erles(self.composite.height, self.composite.width)
-
-    def _num_annotations(self) -> Dict[str, int]:
-        return {"masks": len(self.masks)}
-
-    def _remove_annotation(self, i):
-        self.masks.pop(i)
-
     def _repr(self) -> List[str]:
-        return [f"Masks: {self.masks}"]
+        return [f"masks: {self.masks}", f"mask_array: {self.mask_array}"]
 
     def as_dict(self) -> dict:
-        return {"masks": self.masks}
+        return {"masks": self.masks, "mask_array": self.mask_array}
+
+    def _remove_annotation(self, i):
+        raise NotImplementedError(
+            "_remove_annotation does not work for mask component, if you're getting "
+            "this on autofix, it's probably means this record has to be fixes manually"
+        )
+
+
+class SemanticMaskRecordComponent(BaseMasksRecordComponent):
+    def __init__(self, task=tasks.segmentation):
+        super().__init__(task=task)
+
+    def _builder_template(self) -> List[str]:
+        return ["record{task}set_mask(<Mask>)"]
+
+
+class InstanceMasksRecordComponent(BaseMasksRecordComponent):
+    def __init__(self, task=tasks.detection):
+        super().__init__(task=task)
+
+    def _builder_template(self) -> List[str]:
+        return ["record{task}add_masks(<Sequence[Mask]>)"]
+
+
+# class MasksRecordComponent(RecordComponent):
+#     def __init__(self, task=tasks.detection):
+#         super().__init__(task=task)
+#         self.masks = EncodedRLEs()
+
+#     def set_masks(self, masks: Sequence[Mask]):
+#         self.masks = masks
+
+#     def add_masks(self, masks: Sequence[Mask]):
+#         self.masks.extend(self._masks_to_erle(masks))
+
+#     def setup_transform(self, tfm) -> None:
+#         tfm.setup_masks(self)
+
+#     def _masks_to_erle(self, masks: Sequence[Mask]) -> List[Mask]:
+#         width, height = self.composite.img_size
+#         return [mask.to_erles(h=height, w=width) for mask in masks]
+
+#     def _load(self):
+#         self.masks = MaskArray.from_masks(
+#             self.masks, self.composite.height, self.composite.width
+#         )
+
+#     def _unload(self):
+#         # TODO: SLOW: Maybe cause slowdowns?
+#         self.masks = self.masks.to_erles(self.composite.height, self.composite.width)
+
+#     def _num_annotations(self) -> Dict[str, int]:
+#         return {"masks": len(self.masks)}
+
+#     def _remove_annotation(self, i):
+#         self.masks.pop(i)
+
+#     def _repr(self) -> List[str]:
+#         return [f"Masks: {self.masks}"]
+
+#     def as_dict(self) -> dict:
+#         return {"masks": self.masks}
+
+#     def _builder_template(self) -> List[str]:
+#         return ["record{task}add_masks(<Sequence[Mask]>)"]
+
+
+# class SemanticMasksRecordComponent(RecordComponent):
+#     def __init__(self, task=tasks.segmentation):
+#         super().__init__(task=task)
+#         # HACK: unloaded_mask is a hacky solution
+#         self._unloaded_mask: Mask = None
+#         self.masks: Sequence[Mask] = None
+
+#     def set_mask(self, mask: Mask):
+#         self._unloaded_mask = [mask]
+#         # HACK: list here just because is what we need on instance segmentation
+#         self.masks = [mask]
+
+#     # HACK: only here because it's what albumentations call
+#     def set_masks(self, masks: Mask):
+#         self.masks = masks
+#         # assert len(masks) == 1, "can only be a single mask for segmentation"
+#         # self.set_mask(masks[0])
+
+#     def setup_transform(self, tfm) -> None:
+#         tfm.setup_masks(self)
+
+#     def _load(self):
+#         self.masks = MaskArray.from_masks(
+#             self.masks, self.composite.height, self.composite.width
+#         )
+
+#     def _unload(self):
+#         self.masks = None
+
+#     # def _num_annotations(self) -> Dict[str, int]:
+#     #     return {"masks": len(self.masks)}
+
+#     # def _remove_annotation(self, i):
+#     #     self.masks.pop(i)
+
+#     def _repr(self) -> List[str]:
+#         return [f"Masks: {self.masks}"]
+
+#     def _builder_template(self) -> List[str]:
+#         return ["record{task}set_masks(<Sequence[Mask]>)"]
 
 
 class AreasRecordComponent(RecordComponent):
