@@ -1,6 +1,7 @@
 import sys, os, re, shutil, typing, itertools, operator, math, warnings, json, random
 import functools, io, cv2, mimetypes, torch, torchvision, dataclasses, zipfile, pickle
-from copy import deepcopy
+import PIL
+from copy import copy, deepcopy
 
 from pdb import set_trace
 from dataclasses import dataclass
@@ -28,7 +29,7 @@ from abc import (
     abstractstaticmethod,
 )
 from pathlib import Path
-from collections import defaultdict, OrderedDict
+from collections import defaultdict, OrderedDict, namedtuple
 from enum import Enum
 from tqdm.auto import tqdm
 from pycocotools import mask as mask_utils
@@ -62,10 +63,14 @@ if SoftDependencies.fastai:
 
 if SoftDependencies.pytorch_lightning:
     import pytorch_lightning as pl
+    from pytorch_lightning import loggers as pl_loggers
 
 if SoftDependencies.wandb:
     import wandb
 
+if SoftDependencies.sklearn:
+    import sklearn
+
 
 # TODO: Stop importing partial from fastcore and move this to utils
 class partial:
