@@ -13,15 +13,9 @@ def model(
     num_classes: int,
     checkpoints_path: Optional[Union[str, Path]] = "checkpoints",
     force_download=False,
+    cfg_options=None,
 ) -> nn.Module:
 
-    cfg, weights_path = create_model_config(
-        backbone=backbone,
-        pretrained=backbone.pretrained,
-        checkpoints_path=checkpoints_path,
-        force_download=force_download,
-    )
-
     return build_model(
         model_type="two_stage_detector_bbox",
         backbone=backbone,
@@ -29,4 +23,5 @@ def model(
         pretrained=backbone.pretrained,
         checkpoints_path=checkpoints_path,
         force_download=force_download,
+        cfg_options=cfg_options,
     )
