@@ -5,6 +5,7 @@ __all__ = [
     "build_model",
 ]
 
+from icevision import backbones
 from icevision.imports import *
 from icevision.utils import *
 from mmcv import Config
@@ -55,6 +56,7 @@ def build_model(
         if isinstance(cfg.model.roi_head.bbox_head, list):
             for bbox_head in cfg.model.roi_head.bbox_head:
                 bbox_head["num_classes"] = num_classes - 1
+
         else:
             cfg.model.roi_head.bbox_head.num_classes = num_classes - 1
 
@@ -62,6 +64,11 @@ def build_model(
         cfg.model.roi_head.bbox_head.num_classes = num_classes - 1
         cfg.model.roi_head.mask_head.num_classes = num_classes - 1
 
+    if model_type == "one_stage_detector_mask":
+        cfg.model.bbox_head.num_classes = num_classes - 1
+        cfg.model.segm_head.num_classes = num_classes - 1
+        cfg.model.mask_head.num_classes = num_classes - 1
+
     if (pretrained == False) or (weights_path is not None):
         cfg.model.pretrained = None
 
