@@ -1,6 +1,7 @@
 # object detection
 from icevision.models.mmdet.models import faster_rcnn
 from icevision.models.mmdet.models import yolox
+from icevision.models.mmdet.models import yolof
 from icevision.models.mmdet.models import retinanet
 from icevision.models.mmdet.models import fcos
 from icevision.models.mmdet.models import vfnet
@@ -8,6 +9,11 @@ from icevision.models.mmdet.models import cornernet
 from icevision.models.mmdet.models import centripetalnet
 from icevision.models.mmdet.models import sparse_rcnn
 from icevision.models.mmdet.models import ssd
+from icevision.models.mmdet.models import detr
+from icevision.models.mmdet.models import deformable_detr
+from icevision.models.mmdet.models import fsaf
+from icevision.models.mmdet.models import sabl
 
 # segmentation
 from icevision.models.mmdet.models import mask_rcnn
+from icevision.models.mmdet.models import yolact
