@@ -1,4 +1,4 @@
-__all__ = ["predict", "predict_from_dl", "convert_raw_predictions"]
+__all__ = ["predict", "predict_from_dl", "convert_raw_predictions", "end2end_detect"]
 
 from icevision.imports import *
 from icevision.utils import *
@@ -7,6 +7,7 @@ from icevision.data import *
 from icevision.models.utils import _predict_from_dl
 from icevision.models.ultralytics.yolov5.dataloaders import *
 from yolov5.utils.general import non_max_suppression
+from icevision.models.inference import *
 
 
 @torch.no_grad()
@@ -107,7 +108,7 @@ def convert_raw_predictions(
         )
 
         pred.detection.set_class_map(record.detection.class_map)
-        pred.detection.set_labels_by_id(det[:, 5].astype(int))
+        pred.detection.set_labels_by_id(det[:, 5].astype(int) + 1)
         pred.detection.set_bboxes([BBox.from_xyxy(*xyxy) for xyxy in det[:, :4]])
         pred.detection.set_scores(det[:, 4])
 
@@ -117,3 +118,6 @@ def convert_raw_predictions(
         preds.append(Prediction(pred=pred, ground_truth=record))
 
     return preds
+
+
+end2end_detect = partial(_end2end_detect, predict_fn=predict)
