@@ -1,5 +1,4 @@
 __all__ = [
-    "coco",
     "COCOBaseParser",
     "COCOBBoxParser",
     "COCOMaskParser",
@@ -13,25 +12,32 @@ from icevision.utils import *
 from icevision.parsers import *
 
 
-def coco(
-    annotations_file: Union[str, Path],
-    img_dir: Union[str, Path],
-    mask: bool = True,
-) -> Parser:
-    parser_cls = COCOMaskParser if mask else COCOBBoxParser
-    return parser_cls(annotations_file, img_dir)
-
-
-class COCOBaseParser(
-    Parser, FilepathMixin, SizeMixin, LabelsMixin, AreasMixin, IsCrowdsMixin
-):
+class COCOBaseParser(Parser):
     def __init__(
-        self, annotations_filepath: Union[str, Path], img_dir: Union[str, Path]
+        self,
+        annotations_filepath: Union[str, Path, dict],
+        img_dir: Union[str, Path],
+        idmap: Optional[IDMap] = None,
     ):
-        self.annotations_dict = json.loads(Path(annotations_filepath).read_bytes())
+
+        if isinstance(annotations_filepath, dict):
+            self.annotations_dict = annotations_filepath
+        else:
+            self.annotations_dict = json.loads(Path(annotations_filepath).read_bytes())
         self.img_dir = Path(img_dir)
 
-        self._imageid2info = {o["id"]: o for o in self.annotations_dict["images"]}
+        self._record_id2info = {o["id"]: o for o in self.annotations_dict["images"]}
+
+        categories = self.annotations_dict["categories"]
+        id2class = {o["id"]: o["name"] for o in categories}
+        id2class[0] = BACKGROUND
+        # coco has non sequential ids, we fill the blanks with `None`, check #668 for more info
+        classes = [None for _ in range(max(id2class.keys()) + 1)]
+        for i, name in id2class.items():
+            classes[i] = name
+        self.class_map = ClassMap(classes)
+
+        super().__init__(template_record=self.template_record(), idmap=idmap)
 
     def __iter__(self):
         yield from self.annotations_dict["annotations"]
@@ -39,19 +45,29 @@ class COCOBaseParser(
     def __len__(self):
         return len(self.annotations_dict["annotations"])
 
-    def prepare(self, o):
-        self._info = self._imageid2info[o["image_id"]]
+    def template_record(self) -> BaseRecord:
+        return BaseRecord(
+            (
+                FilepathRecordComponent(),
+                InstancesLabelsRecordComponent(),
+                AreasRecordComponent(),
+                IsCrowdsRecordComponent(),
+            )
+        )
 
-    def imageid(self, o) -> int:
+    def prepare(self, o):
+        self._info = self._record_id2info[o["image_id"]]
+
+    def record_id(self, o) -> int:
         return o["image_id"]
 
     def filepath(self, o) -> Path:
         return self.img_dir / self._info["file_name"]
 
-    def image_width_height(self, o) -> Tuple[int, int]:
-        return get_image_size(self.filepath(o))
+    def img_size(self, o) -> ImgSize:
+        return get_img_size(self.filepath(o))
 
-    def labels(self, o) -> List[int]:
+    def labels_ids(self, o) -> List[Hashable]:
         return [o["category_id"]]
 
     def areas(self, o) -> List[float]:
@@ -60,13 +76,33 @@ class COCOBaseParser(
     def iscrowds(self, o) -> List[bool]:
         return [o["iscrowd"]]
 
+    def parse_fields(self, o, record, is_new):
+        if is_new:
+            record.set_filepath(self.filepath(o))
+            record.set_img_size(self.img_size(o))
 
-class COCOBBoxParser(COCOBaseParser, BBoxesMixin):
+        # TODO: is class_map still a issue here?
+        record.detection.set_class_map(self.class_map)
+        record.detection.add_labels_by_id(self.labels_ids(o))
+        record.detection.add_areas(self.areas(o))
+        record.detection.add_iscrowds(self.iscrowds(o))
+
+
+class COCOBBoxParser(COCOBaseParser):
     def bboxes(self, o) -> List[BBox]:
         return [BBox.from_xywh(*o["bbox"])]
 
+    def template_record(self) -> BaseRecord:
+        record = super().template_record()
+        record.add_component(BBoxesRecordComponent())
+        return record
 
-class COCOMaskParser(COCOBBoxParser, MasksMixin):
+    def parse_fields(self, o, record, is_new):
+        super().parse_fields(o, record, is_new=is_new)
+        record.detection.add_bboxes(self.bboxes(o))
+
+
+class COCOMaskParser(COCOBBoxParser):
     def masks(self, o) -> List[MaskArray]:
         seg = o["segmentation"]
         if o["iscrowd"]:
@@ -74,8 +110,22 @@ class COCOMaskParser(COCOBBoxParser, MasksMixin):
         else:
             return [Polygon(seg)]
 
+    def template_record(self) -> BaseRecord:
+        record = super().template_record()
+        record.add_component(InstanceMasksRecordComponent())
+        return record
+
+    def parse_fields(self, o, record, is_new):
+        super().parse_fields(o, record, is_new=is_new)
+        record.detection.add_masks(self.masks(o))
+
+
+class COCOKeyPointsParser(COCOBBoxParser):
+    def template_record(self) -> BaseRecord:
+        record = super().template_record()
+        record.add_component(KeyPointsRecordComponent())
+        return record
 
-class COCOKeyPointsParser(COCOBBoxParser, KeyPointsMixin):
     def keypoints(self, o) -> List[KeyPoints]:
         return (
             [KeyPoints.from_xyv(o["keypoints"], COCOKeypointsMetadata)]
@@ -83,8 +133,10 @@ class COCOKeyPointsParser(COCOBBoxParser, KeyPointsMixin):
             else []
         )
 
-    def labels(self, o) -> List[int]:
-        return [o["category_id"]] if sum(o["keypoints"]) > 0 else []
+    def labels_ids(self, o) -> List[Hashable]:
+        if sum(o["keypoints"]) <= 0:
+            return []
+        return super().labels_ids(o)
 
     def areas(self, o) -> List[float]:
         return [o["area"]] if sum(o["keypoints"]) > 0 else []
@@ -95,6 +147,10 @@ class COCOKeyPointsParser(COCOBBoxParser, KeyPointsMixin):
     def bboxes(self, o) -> List[BBox]:
         return [BBox.from_xywh(*o["bbox"])] if sum(o["keypoints"]) > 0 else []
 
+    def parse_fields(self, o, record, is_new):
+        super().parse_fields(o, record, is_new=is_new)
+        record.detection.add_keypoints(self.keypoints(o))
+
 
 class COCOConnectionsColor:
     head = (220, 30, 200)
