@@ -3,7 +3,7 @@ __all__ = ["via", "VIAParseError", "VIABaseParser", "VIABBoxParser"]
 from icevision.imports import *
 from icevision.core import *
 from icevision.utils import *
-from icevision.parsers import *
+from icevision.parsers.parser import *
 
 
 def via(
@@ -34,18 +34,31 @@ class VIAParseError(Exception):
     pass
 
 
-class VIABaseParser(Parser, FilepathMixin, LabelsMixin):
+class VIABaseParser(Parser):
     def __init__(
         self,
-        annotations_filepath: Union[str, Path],
+        annotations_filepath: Union[str, Path, dict],
         img_dir: Union[str, Path],
-        cls_map: ClassMap,
+        class_map: ClassMap,
         label_field: str = "label",
     ):
-        self.annotations_dict = json.loads(Path(annotations_filepath).read_bytes())
+        super().__init__(template_record=self.template_record())
+        if isinstance(annotations_filepath, dict):
+            self.annotations_dict = annotations_filepath
+        else:
+            self.annotations_dict = json.loads(Path(annotations_filepath).read_bytes())
         self.img_dir = Path(img_dir)
-        self.cls_map = cls_map
         self.label_field = label_field
+        self.class_map = class_map
+
+    def template_record(self) -> BaseRecord:
+        return BaseRecord(
+            (
+                FilepathRecordComponent(),
+                InstancesLabelsRecordComponent(),
+                BBoxesRecordComponent(),
+            )
+        )
 
     def __iter__(self):
         yield from self.annotations_dict.values()
@@ -53,24 +66,32 @@ class VIABaseParser(Parser, FilepathMixin, LabelsMixin):
     def __len__(self):
         return len(self.annotations_dict.values())
 
-    def imageid(self, o) -> Hashable:
+    def record_id(self, o) -> Hashable:
         return o["filename"]
 
+    def parse_fields(self, o, record, is_new):
+        if is_new:
+            record.set_filepath(self.filepath(o))
+            record.set_img_size(self.image_width_height(o))
+
+        record.detection.set_class_map(self.class_map)
+        record.detection.add_labels(self.labels(o))
+
     def filepath(self, o) -> Path:
         return self.img_dir / f"{o['filename']}"
 
     def image_width_height(self, o) -> Tuple[int, int]:
-        return get_image_size(self.filepath(o))
+        return get_img_size(self.filepath(o))
 
     def _get_label(self, o, region_attributes: dict) -> str:
         label = region_attributes.get(self.label_field)
         if label is None:
             raise VIAParseError(
-                f"Could not find label_field [{self.label_field}] while parsing [{self.imageid(o)}]"
+                f"Could not find label_field [{self.label_field}] while parsing [{self.record_id(o)}]"
             )
         elif not isinstance(label, str):
             raise VIAParseError(
-                f"Non-string value found in label_field [{self.label_field}] while parsing [{self.imageid(o)}]"
+                f"Non-string value found in label_field [{self.label_field}] while parsing [{self.record_id(o)}]"
             )
         return label
 
@@ -78,22 +99,26 @@ class VIABaseParser(Parser, FilepathMixin, LabelsMixin):
         labels = []
         for shape in o["regions"]:
             label = self._get_label(o, shape["region_attributes"])
-            if label in self.cls_map.class2id:
-                labels.append(self.cls_map.get_name(label))
+            if label in self.class_map._class2id:
+                labels.append(label)
         return labels
 
 
-class VIABBoxParser(VIABaseParser, BBoxesMixin):
+class VIABBoxParser(VIABaseParser):
     """
     VIABBoxParser parses `polygon` and `rect` shape attribute types. Polygons
     are converted into bboxes that surround the entire shape.
     """
 
+    def parse_fields(self, o, record, is_new):
+        super().parse_fields(o, record, is_new=is_new)
+        record.detection.add_bboxes(self.bboxes(o))
+
     def bboxes(self, o) -> List[BBox]:
         boxes = []
         for shape in o["regions"]:
             label = self._get_label(o, shape["region_attributes"])
-            if label in self.cls_map.class2id:
+            if label in self.class_map._class2id:
                 shape_attr = shape["shape_attributes"]
                 if shape_attr["name"] == "polygon":
                     x, y = shape_attr["all_points_x"], shape_attr["all_points_y"]
