@@ -25,6 +25,8 @@ class _SoftDependencies:
         self.mmdet = soft_import("mmdet")
         self.yolov5 = soft_import("yolov5")
         self.sklearn = soft_import("sklearn")
+        self.sahi = soft_import("sahi")
+        self.fiftyone = soft_import("fiftyone")
 
     def check(self) -> Dict[str, bool]:
         return self.__dict__.copy()
