@@ -23,15 +23,24 @@ for _EXIF_ORIENTATION_TAG in ExifTags.TAGS.keys():
 #     blah
 
 # FIXME
-def open_img(fn, gray=False) -> PIL.Image.Image:
+def open_img(fn, gray=False, ignore_exif: bool = False) -> PIL.Image.Image:
     "Open an image from disk `fn` as a PIL Image"
     color = "L" if gray else "RGB"
     image = PIL.Image.open(str(fn))
-    image = PIL.ImageOps.exif_transpose(image)
+    if not ignore_exif:
+        image = PIL.ImageOps.exif_transpose(image)
     image = image.convert(color)
     return image
 
 
+def open_gray_scale_image(fn):
+    "Opens an radiographic/gray scale image, stacks the channel to represent a RGB image and returns is as a 32bit float array."
+    img = np.array(PIL.Image.open(fn))
+    img = np.dstack([img, img, img])
+    img = img.astype(np.float32)
+    return img
+
+
 # TODO: Deprecated
 def get_image_size(filepath: Union[str, Path]) -> Tuple[int, int]:
     """
